==> satellite-system-2015.1-sources.jar: com/xebialabs/deployit/plugin/satellite/StreamingSupervisor.scala <==
package com.xebialabs.deployit.plugin.satellite

import akka.actor._
import akka.stream.scaladsl._
import akka.util.ByteString
import com.xebialabs.deployit.engine.tasker.TaskId
import com.xebialabs.deployit.engine.tasker.satellite.SatellitePath
import com.xebialabs.deployit.plugin.api.flow.ExecutionContext
import com.xebialabs.deployit.plugin.satellite.StreamingSupervisor.UploadRequest
import com.xebialabs.overthere.OverthereFile
import com.xebialabs.satellite.protocol.UploadId
import com.xebialabs.satellite.serialization.ArtifactId

class StreamingSupervisor extends Actor {

  val log = akka.event.Logging(context.system, classOf[StreamingSupervisor])

  def receive: Receive = {
    case request: UploadRequest =>
      val fileUploadProps: Props = FileUploader.props(sender(), request)
      context.actorOf(fileUploadProps, request.id.toString) forward request
  }

}

object StreamingSupervisor {

  case class UploadRequest(taskId: TaskId,
                           artifactId: ArtifactId,
                           overthereFile: OverthereFile,
                           ctx: ExecutionContext,
                           satellite: SatellitePath,
                           satelliteHostname: String,
                           id: UploadId = UploadId())

  def props(): Props = Props[StreamingSupervisor]

  private val reflectionIssueWorkaround = FlowGraph { implicit builder =>
    val merge = Merge[ByteString]
    val flow = Source(List(ByteString.empty))

    builder.
      addEdge(flow, merge).
      addEdge(flow, merge).addEdge(merge, Flow[ByteString].to(BlackholeSink))
  }

}

==> satellite-system-2015.2.11-sources.jar: com/xebialabs/deployit/plugin/satellite/StreamingSupervisor.scala <==
package com.xebialabs.deployit.plugin.satellite

import akka.actor._
import akka.stream.scaladsl._
import akka.util.ByteString
import com.xebialabs.deployit.engine.tasker.TaskId
import com.xebialabs.deployit.engine.tasker.satellite.ActorLocator
import com.xebialabs.deployit.plugin.api.flow.ExecutionContext
import com.xebialabs.deployit.plugin.satellite.StreamingSupervisor.UploadRequest
import com.xebialabs.overthere.OverthereFile
import com.xebialabs.satellite.protocol.UploadId
import com.xebialabs.satellite.serialization.ArtifactId

class StreamingSupervisor extends Actor {

  val log = akka.event.Logging(context.system, classOf[StreamingSupervisor])

  def receive: Receive = {
    case request: UploadRequest =>
      val fileUploadProps: Props = FileUploader.props(sender(), request)
      context.actorOf(fileUploadProps, request.id.toString) forward request
  }

}

object StreamingSupervisor {

  case class UploadRequest(taskId: TaskId,
                           artifactId: ArtifactId,
                           overthereFile: OverthereFile,
                           ctx: ExecutionContext,
                           satellite: ActorLocator,
                           satelliteHostname: String,
                           id: UploadId = UploadId())

  def props(): Props = Props[StreamingSupervisor]

  private val reflectionIssueWorkaround = FlowGraph { implicit builder =>
    val merge = Merge[ByteString]
    val flow = Source(List(ByteString.empty))

    builder.
      addEdge(flow, merge).
      addEdge(flow, merge).addEdge(merge, Flow[ByteString].to(BlackholeSink))
  }

}
